"use client";

import { Github, Linkedin, Twitter } from "lucide-react";

const quickLinks = [
  { name: "Home", href: "/" },
  { name: "About", href: "#about" },
  { name: "Program", href: "#program" },
  { name: "Speakers", href: "#speakers" },
  { name: "Call For Papers", href: "#call-for-papers" },
  { name: "Conference Theme", href: "#conference-theme" },
  { name: "Registration", href: "#registration-fee" },
  { name: "Submission", href: "#submission" },
  { name: "Publications", href: "#publications" },
];

const Footer = () => {
  const handleClick = (e: React.MouseEvent<HTMLAnchorElement>, href: string) => {
    e.preventDefault();
    
    if (href === "/") {
      window.scrollTo({ top: 0, behavior: "smooth" });
    } else {
      const element = document.querySelector(href);
      if (element) {
        const headerOffset = 80; // Height of your fixed header
        const elementPosition = element.getBoundingClientRect().top;
        const offsetPosition = elementPosition + window.pageYOffset - headerOffset;

        window.scrollTo({
          top: offsetPosition,
          behavior: "smooth",
        });
      }
    }
  };

  return (
    <footer className="bg-white border-t border-gray-100">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-12">
        <div className="grid grid-cols-1 md:grid-cols-3 gap-12">
          {/* Quick Links */}
          <div>
            <h3 className="text-lg font-semibold text-gray-900 mb-4">
              Quick Links
            </h3>
            <ul className="space-y-3">
              {quickLinks.map((link) => (
                <li key={link.name}>
                  <a
                    href={link.href}
                    onClick={(e) => handleClick(e, link.href)}
                    className="text-gray-600 hover:text-primary transition-colors"
                  >
                    {link.name}
                  </a>
                </li>
              ))}
            </ul>
          </div>

          {/* Connect With Us */}
          <div>
            <h3 className="text-lg font-semibold text-gray-900 mb-4">
              Connect With Us
            </h3>
            {/* Social Links */}
            <div className="flex gap-4 mb-6">
              <a
                href="https://twitter.com/aiou"
                target="_blank"
                rel="noopener noreferrer"
                className="w-10 h-10 bg-gray-50 rounded-lg flex items-center justify-center text-gray-600 hover:text-primary hover:bg-gray-100 transition-colors"
              >
                <Twitter className="w-5 h-5" />
              </a>
              <a
                href="https://linkedin.com/company/aiou"
                target="_blank"
                rel="noopener noreferrer"
                className="w-10 h-10 bg-gray-50 rounded-lg flex items-center justify-center text-gray-600 hover:text-primary hover:bg-gray-100 transition-colors"
              >
                <Linkedin className="w-5 h-5" />
              </a>
              <a
                href="https://github.com/aiou"
                target="_blank"
                rel="noopener noreferrer"
                className="w-10 h-10 bg-gray-50 rounded-lg flex items-center justify-center text-gray-600 hover:text-primary hover:bg-gray-100 transition-colors"
              >
                <Github className="w-5 h-5" />
              </a>
            </div>
            {/* Address */}
            <address className="text-gray-600 not-italic">
              <p className="mb-1">Allama Iqbal Open University</p>
              <p className="mb-1">Sector H-8, Islamabad</p>
              <p>Pakistan</p>
            </address>
          </div>

          {/* Stay Updated */}
          <div>
            <h3 className="text-lg font-semibold text-gray-900 mb-4">
              Stay Updated
            </h3>
            <p className="text-gray-600 mb-4">
              Subscribe to our newsletter for updates and announcements
            </p>
            <form className="space-y-3">
              <input
                type="email"
                placeholder="Enter your email"
                className="w-full px-4 py-2 rounded-lg border border-gray-200 focus:outline-none focus:ring-2 focus:ring-primary/20 focus:border-primary transition-colors"
              />
              <button
                type="submit"
                className="w-full px-4 py-2 bg-black text-white rounded-lg hover:bg-gray-800 transition-colors"
              >
                Subscribe
              </button>
            </form>
          </div>
        </div>

        {/* Copyright */}
        <div className="mt-12 pt-8 border-t border-gray-100 text-center text-gray-600">
          <p> 2025 AIOU-NCCT. All rights reserved.</p>
        </div>
      </div>
    </footer>
  );
};

export default Footer;
