const About = () => {
  return (
    <section id="about" className="py-20 bg-white">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        {/* Section Header */}
        <div className="text-center mb-16">
          <h2 className="text-3xl md:text-4xl font-bold mb-4">
            About the Conference
          </h2>
          <div className="w-20 h-1 bg-primary mx-auto rounded-full mb-6" />
          <p className="text-gray-600 max-w-6xl mx-auto text-center text-justify ">
          National Accreditation Council for Teacher Education Islamabad and Department of Secondary Teacher Education  
          Allama Iqbal Open University is jointly organizing an International Conference on Quality Teacher Education at AIOU Islamabad. 
          This international conference will provide a platform to the academicians, professionals, administrators, policy makers, curriculum developers to gather the experiences based on research-based knowledge and furnish valuable recommendations to cope with the challenges of Teacher Education. 
          The sessions will aim at addressing the emerging issues and challenges in the teacher education This forum will also provide an opportunity to the renowned national and international academicians to conclude the ultimate possibilities and guidelines for teachers licencing, accreditation of teacher education programs, teacher education roadmap, recruitment of trained teachers & teachers’ induction and career pathways.
          </p>
        </div>

        {/* Features Grid */}
        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
          {/* Vision */}
          <div className="p-6 rounded-2xl bg-gray-50 hover:bg-gray-100/80 transition-colors group">
            <div className="w-12 h-12 bg-primary/10 rounded-xl flex items-center justify-center mb-4 group-hover:bg-primary/20 transition-colors">
              <svg 
                xmlns="http://www.w3.org/2000/svg" 
                className="h-6 w-6 text-primary"
                fill="none"
                viewBox="0 0 24 24"
                stroke="currentColor"
              >
                <path 
                  strokeLinecap="round" 
                  strokeLinejoin="round" 
                  strokeWidth={2} 
                  d="M9 12l2 2 4-4m6 2a9 9 0 11-18 0 9 9 0 0118 0z" 
                />
              </svg>
            </div>
            <h3 className="text-2xl font-semibold mb-2">Event Relevance & Scientific Significance</h3>
            <p className="text-gray-600 text-justify">
            Quality of teacher education is a critical determinant of student learning outcomes and overall educational achievement. However, many countries, including Pakistan face challenges in ensuring that teacher education programs are of high quality, relevant, and effective in preparing teachers for the classroom.
The objective of this conference is to bring together stakeholders, including policymakers, educators, researchers, and practitioners, to discuss and share best practices on enhancing teachers’ quality through effective teacher education, licensing, accreditation, and curriculum reforms.

            </p>
          </div>

          {/* Objectives */}
          <div className="p-6 rounded-2xl bg-gray-50 hover:bg-gray-100/80 transition-colors group">
            <div className="w-12 h-12 bg-primary/10 rounded-xl flex items-center justify-center mb-4 group-hover:bg-primary/20 transition-colors">
              <svg 
                xmlns="http://www.w3.org/2000/svg" 
                className="h-6 w-6 text-primary"
                fill="none"
                viewBox="0 0 24 24"
                stroke="currentColor"
              >
                <path 
                  strokeLinecap="round" 
                  strokeLinejoin="round" 
                  strokeWidth={2} 
                  d="M19 11H5m14 0a2 2 0 012 2v6a2 2 0 01-2 2H5a2 2 0 01-2-2v-6a2 2 0 012-2m14 0V9a2 2 0 00-2-2M5 11V9a2 2 0 012-2m0 0V5a2 2 0 012-2h6a2 2 0 012 2v2M7 7h10" 
                />
              </svg>
            </div>
            <h3 className="text-2xl font-semibold mb-2">Conference Aims</h3>
            {/* <ul className="text-gray-600 space-y-2"> */}
              {/* <li>• Share innovative teaching methodologies</li>
              <li>• Foster collaboration between institutions</li>
              <li>• Promote research in education</li>
              <li>• Address challenges in teacher education</li> */}

              <p className="text-gray-600 text-justify">
              This international conference aims to serve as a platform for academicians, professionals, administrators, policymakers, 
              and curriculum developers to exchange research-based knowledge and experiences in addressing the challenges of teacher education. 
              The conference intends to foster collaboration and generate valuable recommendations to enhance teacher education practices and policies. 
              It seeks to provide insights into the emerging issues and opportunities in the field of teacher education, ultimately contributing to the improvement of 
              teaching standards and professional growth.
              </p>
            {/* </ul> */}
          </div>

          {/* Highlights */}
          <div className="p-6 rounded-2xl bg-gray-50 hover:bg-gray-100/80 transition-colors group">
            <div className="w-12 h-12 bg-primary/10 rounded-xl flex items-center justify-center mb-4 group-hover:bg-primary/20 transition-colors">
              <svg 
                xmlns="http://www.w3.org/2000/svg" 
                className="h-6 w-6 text-primary"
                fill="none"
                viewBox="0 0 24 24"
                stroke="currentColor"
              >
                <path 
                  strokeLinecap="round" 
                  strokeLinejoin="round" 
                  strokeWidth={2} 
                  d="M11 3.055A9.001 9.001 0 1020.945 13H11V3.055z" 
                />
                <path 
                  strokeLinecap="round" 
                  strokeLinejoin="round" 
                  strokeWidth={2} 
                  d="M20.488 9H15V3.512A9.025 9.025 0 0120.488 9z" 
                />
              </svg>
            </div>
            <h3 className="text-2xl font-semibold mb-2">Conference Objectives</h3>
            <ul className="text-gray-600 space-y-2 text-justify">
              <li>• To bring together national and international experts, academicians, and 
                professionals to discuss the challenges and opportunities in teacher education.</li>
              <li>• To explore emerging issues in teacher education, including licensing, accreditation, and program development.s</li>
              <li>• To provide guidelines for the development of teacher education roadmaps, recruitment practices, and induction processes.</li>
              <li>• To discuss career pathways for teachers, including professional development opportunities and long-term growth strategies.</li>
              <li>• To create a collaborative forum that fosters dialogue and partnerships between researchers, practitioners, and decision-makers in teacher education.</li>
            </ul>
          </div>
        </div>

        {/* Bottom Content */}
        {/* <div className="mt-16 text-center">
          <div className="inline-flex items-center justify-center p-8 rounded-2xl bg-primary/5 max-w-3xl mx-auto">
            <p className="text-gray-700 italic">
              "Join us in shaping the future of education through quality teacher training and professional development. Together, we can create a lasting impact on the educational landscape of Pakistan."
            </p>
          </div>
        </div> */}
      </div>
    </section>
  );
};

export default About;