"use client";

import { Calendar } from "lucide-react";

interface ImportantDate {
  title: string;
  date: string;
  isHighlighted?: boolean;
}

const importantDates: ImportantDate[] = [
  {
    title: "Call for Papers",
    date: "12 January, 2025",
  },
  {
    title: "* Abstract Submission Deadline",
    date: "28 February, 2025",
  },
  {
    title: "Notification of Abstract Acceptance",
    date: "15 March, 2025",
  },
  {
    title: "** Full Paper Submission Deadline",
    date: "15 April, 2025",
  },
  {
    title: "Early Bird Registration Deadline",
    date: "15 April, 2025",
  },
  {
    title: "Deadline for Registration",
    date: "30 April, 2025",
  },
];

const CallForPapers = () => {
  return (
    <section id="call-for-papers" className="py-20 bg-gray-50">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        {/* Section Header */}
        <div className="text-center mb-16">
          <h2 className="text-3xl md:text-4xl font-bold mb-4">
            Call For Papers
          </h2>
          <div className="w-20 h-1 bg-primary mx-auto rounded-full mb-6" />
          <p className="text-gray-600 max-w-2xl mx-auto">
            Important dates and deadlines for paper submission and registration
          </p>
        </div>

        {/* Timeline */}
        <div className="max-w-3xl mx-auto">
          {importantDates.map((item, index) => (
            <div key={index} className="relative pl-8 pb-8 group">
              {/* Timeline line */}
              {index !== importantDates.length - 1 && (
                <div className="absolute left-[11px] top-3 bottom-0 w-px bg-gray-200 group-hover:bg-primary/20 transition-colors" />
              )}

              {/* Timeline dot */}
              <div
                className={`absolute left-0 top-1 w-[23px] h-[23px] rounded-full border-4 border-white shadow-sm transition-colors ${
                  item.isHighlighted ? "bg-primary" : "bg-primary/40"
                }`}
              />

              {/* Content */}
              <div
                className={`bg-white rounded-xl p-6 shadow-sm hover:shadow-md transition-all ${
                  item.isHighlighted ? "ring-1 ring-primary/10" : ""
                }`}
              >
                <div className="flex flex-col sm:flex-row sm:items-center sm:justify-between gap-2">
                  <div className="flex items-center gap-2">
                    <Calendar className="w-5 h-5 text-primary/60" />
                    <h3
                      className={`font-semibold ${
                        item.isHighlighted ? "text-primary" : "text-gray-900"
                      }`}
                    >
                      {item.title}
                    </h3>
                  </div>
                  <span className="text-gray-500 text-sm">{item.date}</span>
                </div>
                {item.isHighlighted && (
                  <div className="mt-2 text-sm text-primary/60 pl-7">
                    * Important deadline
                  </div>
                )}
              </div>
            </div>
          ))}
        </div>

        {/* Note */}
        <div className="mt-12 max-w-3xl mx-auto">
          <div className="bg-primary/5 rounded-xl p-6 text-center">
            <p className="text-gray-600 text-sm">
              Please ensure to submit your papers before the deadlines. Late
              submissions may not be considered for review.
            </p>
          </div>
        </div>
      </div>
    </section>
  );
};

export default CallForPapers;
