"use client";

import { ChevronDown, ChevronUp, BookOpen, Users, GraduationCap, BookOpenCheck, Award, UserPlus2, UserCheck } from "lucide-react";
import { useState } from "react";

interface ThemeItem {
  title: string;
  topics: string[];
}

interface Theme {
  icon: JSX.Element;
  mainTheme: string;
  items: ThemeItem[];
}

const themes: Theme[] = [
  {
    icon: <Award className="w-6 h-6" />,
    mainTheme: "Teachers' Licensing",
    items: [
      {
        title: "Global Practices and Trends in Teachers' Licensing",
        topics: [],
      },
      {
        title: "Policy Frameworks for Teachers' Licensing in Developing Countries",
        topics: [],
      },
      {
        title: "Challenges and Opportunities in Implementing Teacher Licensing Systems",
        topics: [],
      },
      {
        title: "Ensuring Quality Through Teacher Licensing Mechanisms",
        topics: [],
      },
      {
        title: "Role of Licensing in Teacher Professionalism and Accountability",
        topics: [],
      },
    ],
  },
  {
    icon: <GraduationCap className="w-6 h-6" />,
    mainTheme: "Accreditation of Teachers' Education",
    items: [
      {
        title: "Standards and Criteria for Accrediting Teacher Education Programs",
        topics: [],
      },
      {
        title: "International Benchmarks in Accreditation: Lessons for Local Systems",
        topics: [],
      },
      {
        title: "Ensuring Continuous Improvement Through Accreditation Processes",
        topics: [],
      },
      {
        title: "Accreditation and Its Role in Enhancing Teacher Education Quality",
        topics: [],
      },
      {
        title: "Challenges in Aligning Accreditation Standards with National Policies",
        topics: [],
      },
    ],
  },
  {
    icon: <BookOpen className="w-6 h-6" />,
    mainTheme: "Teacher Education Roadmap",
    items: [
      {
        title: "Developing a Comprehensive Teacher Education Policy Framework",
        topics: [],
      },
      {
        title: "Integration of Technology in the Teacher Education Roadmap",
        topics: [],
      },
      {
        title: "Bridging Gaps Between Teacher Education and Market Demands",
        topics: [],
      },
      {
        title: "Defining Long-term Goals for Sustainable Teacher Education Systems",
        topics: [],
      },
      {
        title: "Evaluating the Effectiveness of Existing Teacher Education Roadmaps",
        topics: [],
      },
    ],
  },
  {
    icon: <BookOpenCheck className="w-6 h-6" />,
    mainTheme: "Revamping of Teachers' Education Curriculum",
    items: [
      {
        title: "Incorporating 21st-Century Skills in Teacher Education Curricula",
        topics: [],
      },
      {
        title: "Role of Technology and Digital Tools in Curriculum Development",
        topics: [],
      },
      {
        title: "Embedding Inclusive Education Principles in Teacher Training Programs",
        topics: [],
      },
      {
        title: "Aligning Curricula with Emerging Pedagogical Approaches",
        topics: [],
      },
      {
        title: "Transforming Teacher Education Curriculum to Meet Future Challenges",
        topics: [],
      },
    ],
  },
  {
    icon: <Award className="w-6 h-6" />,
    mainTheme: "Teaching Standards",
    items: [
      {
        title: "Defining and Implementing National Teaching Standards",
        topics: [],
      },
      {
        title: "Role of Standards in Enhancing Teachers' Performance and Accountability",
        topics: [],
      },
      {
        title: "Global Perspectives on Developing and Evaluating Teaching Standards",
        topics: [],
      },
      {
        title: "Embedding Ethical Practices in Teaching Standards Frameworks",
        topics: [],
      },
      {
        title: "Challenges in Maintaining Consistency and Quality in Teaching Standards",
        topics: [],
      },
    ],
  },
  {
    icon: <UserPlus2 className="w-6 h-6" />,
    mainTheme: "Teachers' Induction & Career Pathways",
    items: [
      {
        title: "Designing Effective Teacher Induction Programs for Early Career Teachers",
        topics: [],
      },
      {
        title: "Career Growth and Professional Development Pathways for Teachers",
        topics: [],
      },
      {
        title: "Mentorship Programs and Their Role in Teacher Induction",
        topics: [],
      },
      {
        title: "Addressing Challenges in Career Advancement of Teachers",
        topics: [],
      },
      {
        title: "Balancing Professional and Personal Growth Through Career Pathways",
        topics: [],
      },
    ],
  },
  {
    icon: <UserCheck className="w-6 h-6" />,
    mainTheme: "Recruitment of Trained Teachers",
    items: [
      {
        title: "Policies and Practices for Recruiting High-Quality Teachers",
        topics: [],
      },
      {
        title: "Addressing Teacher Shortages Through Strategic Recruitment Initiatives",
        topics: [],
      },
      {
        title: "Role of Recruitment in Promoting Diversity and Inclusion in Schools",
        topics: [],
      },
      {
        title: "Innovations in Recruitment Processes for Teacher Education Graduates",
        topics: [],
      },
      {
        title: "Evaluating the Impact of Recruitment Strategies on Teacher Retention",
        topics: [],
      },
    ],
  },
];

const ConferenceTheme = () => {
  const [expandedTheme, setExpandedTheme] = useState<number | null>(null);

  return (
    <section id="conference-theme" className="py-20 bg-gray-50">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        {/* Section Header */}
        <div className="text-center mb-16">
          <h2 className="text-3xl md:text-4xl font-bold mb-4">
            Conference Themes
          </h2>
          <div className="w-20 h-1 bg-primary mx-auto rounded-full mb-6" />
          <p className="text-gray-600 max-w-2xl mx-auto">
            Explore our comprehensive conference themes and topics
          </p>
        </div>

        {/* Themes Accordion */}
        <div className="max-w-4xl mx-auto space-y-4">
          {themes.map((theme, index) => (
            <div
              key={index}
              className="bg-white rounded-xl shadow-sm overflow-hidden"
            >
              <button
                onClick={() => setExpandedTheme(expandedTheme === index ? null : index)}
                className="w-full px-6 py-4 flex items-center justify-between hover:bg-gray-50 transition-colors"
              >
                <div className="flex items-center gap-4">
                  <div className="text-primary">{theme.icon}</div>
                  <h3 className="font-semibold text-gray-900 text-left">
                    {theme.mainTheme}
                  </h3>
                </div>
                {expandedTheme === index ? (
                  <ChevronUp className="w-5 h-5 text-gray-500" />
                ) : (
                  <ChevronDown className="w-5 h-5 text-gray-500" />
                )}
              </button>

              {expandedTheme === index && (
                <div className="px-6 pb-4">
                  <div className="pt-4 space-y-2">
                    {theme.items.map((item, itemIndex) => (
                      <div
                        key={itemIndex}
                        className="pl-10 py-2 text-gray-600 hover:text-primary transition-colors"
                      >
                        {item.title}
                      </div>
                    ))}
                  </div>
                </div>
              )}
            </div>
          ))}
        </div>

        {/* Presentation Modes */}
        <div className="mt-16 max-w-4xl mx-auto">
          <div className="bg-white rounded-xl p-6 shadow-sm">
            <h3 className="text-xl font-semibold text-gray-900 mb-4">
              Modes of Presentation
            </h3>
            <div className="flex flex-wrap gap-4">
              {["Oral", "Panel", "Poster", "Online"].map((mode, index) => (
                <div
                  key={index}
                  className="px-4 py-2 bg-primary/5 text-primary rounded-lg font-medium"
                >
                  {mode}
                </div>
              ))}
            </div>
          </div>
        </div>
      </div>
    </section>
  );
};

export default ConferenceTheme;
