"use client";

import { useState } from 'react';
import { Clock, Coffee, Users, Mic, BookOpen, PenTool } from 'lucide-react';

interface TimeSlot {
  time: string;
  title: string;
  description?: string;
  icon: React.ReactNode;
}

const day1Schedule: TimeSlot[] = [
  {
    time: "09:00 AM",
    title: "Opening Ceremony",
    description: "Welcome address and inauguration by chief guest",
    icon: <Mic className="w-5 h-5" />,
  },
  {
    time: "10:00 AM",
    title: "Keynote Session",
    description: "Transforming Teacher Education in Digital Era",
    icon: <BookOpen className="w-5 h-5" />,
  },
  {
    time: "11:30 AM",
    title: "Research Presentations",
    description: "Parallel sessions on innovative teaching methodologies",
    icon: <PenTool className="w-5 h-5" />,
  },
  {
    time: "01:00 PM",
    title: "Lunch Break",
    description: "Networking opportunity with refreshments",
    icon: <Coffee className="w-5 h-5" />,
  },
  {
    time: "02:00 PM",
    title: "Panel Discussion",
    description: "Quality Assurance in Teacher Education",
    icon: <Users className="w-5 h-5" />,
  },
];

const day2Schedule: TimeSlot[] = [
  {
    time: "09:30 AM",
    title: "Workshop Sessions",
    description: "Interactive workshops on teaching methodologies",
    icon: <PenTool className="w-5 h-5" />,
  },
  {
    time: "11:00 AM",
    title: "Technical Sessions",
    description: "Research paper presentations",
    icon: <BookOpen className="w-5 h-5" />,
  },
  {
    time: "01:00 PM",
    title: "Lunch & Networking",
    description: "Break and networking session",
    icon: <Coffee className="w-5 h-5" />,
  },
  {
    time: "02:00 PM",
    title: "Expert Talk",
    description: "Future of Teacher Education in Pakistan",
    icon: <Mic className="w-5 h-5" />,
  },
  {
    time: "04:00 PM",
    title: "Closing Ceremony",
    description: "Certificate distribution and concluding remarks",
    icon: <Users className="w-5 h-5" />,
  },
];

const Program = () => {
  const [activeDay, setActiveDay] = useState<1 | 2>(1);

  return (
    <section id="program" className="py-20 bg-gray-50">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        {/* Section Header */}
        <div className="text-center mb-16">
          <h2 className="text-3xl md:text-4xl font-bold mb-4">
            Conference Program
          </h2>
          <div className="w-20 h-1 bg-primary mx-auto rounded-full mb-6" />
          <p className="text-gray-600 max-w-2xl mx-auto">
            Two days of inspiring sessions, workshops, and networking opportunities
          </p>
        </div>

        {/* Day Selection */}
        <div className="flex justify-center mb-12">
          <div className="inline-flex rounded-lg p-1 bg-gray-100">
            <button
              onClick={() => setActiveDay(1)}
              className={`px-6 py-2 rounded-lg text-sm font-medium transition-colors ${
                activeDay === 1
                  ? 'bg-white text-primary shadow-sm'
                  : 'text-gray-600 hover:text-primary'
              }`}
            >
              Day 1 - May 13
            </button>
            <button
              onClick={() => setActiveDay(2)}
              className={`px-6 py-2 rounded-lg text-sm font-medium transition-colors ${
                activeDay === 2
                  ? 'bg-white text-primary shadow-sm'
                  : 'text-gray-600 hover:text-primary'
              }`}
            >
              Day 2 - May 14
            </button>
          </div>
        </div>

        {/* Timeline */}
        <div className="max-w-3xl mx-auto">
          {(activeDay === 1 ? day1Schedule : day2Schedule).map((slot, index) => (
            <div
              key={index}
              className="relative pl-8 pb-8 group"
            >
              {/* Timeline line */}
              {index !== (activeDay === 1 ? day1Schedule : day2Schedule).length - 1 && (
                <div className="absolute left-[11px] top-3 bottom-0 w-px bg-gray-200 group-hover:bg-primary/20 transition-colors" />
              )}
              
              {/* Timeline dot */}
              <div className="absolute left-0 top-1 w-[23px] h-[23px] rounded-full border-4 border-white bg-primary shadow-sm" />
              
              {/* Content */}
              <div className="bg-white rounded-xl p-4 shadow-sm hover:shadow-md transition-shadow">
                <div className="flex items-center gap-3 mb-2">
                  <Clock className="w-4 h-4 text-primary" />
                  <span className="text-sm font-medium text-primary">
                    {slot.time}
                  </span>
                </div>
                <div className="flex items-start gap-3">
                  <div className="mt-1 p-2 bg-primary/10 rounded-lg">
                    {slot.icon}
                  </div>
                  <div>
                    <h3 className="font-semibold text-gray-900">
                      {slot.title}
                    </h3>
                    {slot.description && (
                      <p className="text-gray-600 text-sm mt-1">
                        {slot.description}
                      </p>
                    )}
                  </div>
                </div>
              </div>
            </div>
          ))}
        </div>
      </div>
    </section>
  );
};

export default Program;