"use client";

import { ExternalLink, BookOpen } from "lucide-react";

interface Journal {
  title: string;
  link: string;
  isExternal?: boolean;
}

const journals: Journal[] = [
  {
    title: "Asian Association of Open Universities Journal (AAOU Journal)",
    link: "https://www.emeraldgrouppublishing.com/journal/aaouj",
    isExternal: true,
  },
  {
    title: "Pakistan Journal of Distance and Online Learning (AIOU Journal)",
    link: "http://pjdol.aiou.edu.pk/",
  },
  {
    title: "Journal of Educational Leadership and Management (JELM) (AIOU Journal)",
    link: "http://jelm.aiou.edu.pk/",
  },
  {
    title: "Journal of Early Childhood Care & Education (JECCE) (AIOU Journal)",
    link: "http://jecce.aiou.edu.pk/",
  },
  {
    title: "Journal of Science Education (JSE) (AIOU Journal)",
    link: "http://jse.aiou.edu.pk/",
  },
  {
    title: "International Journal of Literacy Theory and Practice (IJLTP) (AIOU Journal)",
    link: "https://ojs.aiou.edu.pk/index.php/ijltp",
  },
  {
    title: "Pakistan Journal of Science and Technology (AIOU Journal)",
    link: "http://pjst.aiou.edu.pk/",
  },
  {
    title: "Pakistan Journal of Education (AIOU Journal)",
    link: "https://ojs.aiou.edu.pk/index.php/pje/HomePJE",
  },
  {
    title: "Journal of Social Sciences and Humanities (AIOU Journal)",
    link: "http://jssh.aiou.edu.pk/",
  },
  {
    title: "Journal of Contemporary Teacher Education (AIOU Journal)",
    link: "http://jcte.aiou.edu.pk/",
  },
  {
    title: "Journal of Contemporary Management Sciences (AIOU Journal)",
    link: "http://jcms.aiou.edu.pk/",
  },
];

const Publications = () => {
  return (
    <section id="publications" className="py-20 bg-gray-50">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        {/* Section Header */}
        <div className="text-center mb-16">
          <h2 className="text-3xl md:text-4xl font-bold mb-4">
            Journals for Publications
          </h2>
          <div className="w-20 h-1 bg-primary mx-auto rounded-full mb-6" />
          <p className="text-gray-600 max-w-2xl mx-auto">
            Selected papers will be considered for publication in the following journals
          </p>
        </div>

        {/* Journals Grid */}
        <div className="max-w-4xl mx-auto">
          <div className="grid gap-4">
            {journals.map((journal, index) => (
              <a
                key={index}
                href={journal.link}
                target="_blank"
                rel="noopener noreferrer"
                className="group bg-white rounded-xl p-6 hover:shadow-lg transition-all duration-300 border border-gray-100 flex items-center justify-between"
              >
                <div className="flex items-center gap-4">
                  <div className="w-10 h-10 rounded-lg bg-primary/5 flex items-center justify-center text-primary">
                    <BookOpen className="w-5 h-5" />
                  </div>
                  <h3 className="font-medium text-gray-900 group-hover:text-primary transition-colors">
                    {journal.title}
                  </h3>
                </div>
                <ExternalLink className="w-5 h-5 text-gray-400 group-hover:text-primary transition-colors" />
              </a>
            ))}
          </div>
        </div>

        {/* Note */}
        <div className="mt-12 max-w-4xl mx-auto">
          <div className="bg-primary/5 rounded-xl p-6 text-center">
            <p className="text-gray-600 text-sm">
              The selection of articles does not guarantee acceptance. Only those articles that successfully complete the editorial and peer-review processes will be published.
            </p>
          </div>
        </div>
      </div>
    </section>
  );
};

export default Publications;
