"use client";

interface FeeCategory {
  category: string;
  international: string;
  local: string;
  isEarlyBird?: boolean;
  isRegular?: boolean;
}

const feeCategories: FeeCategory[] = [
  {
    category: "Early bird: NACTE Council Members",
    international: "300",
    local: "3,000",
    isEarlyBird: true,
  },
  {
    category: "Early bird: Non-NACTE Council Members",
    international: "350",
    local: "3,500",
    isEarlyBird: true,
  },
  {
    category: "Regular: NACTE Council Members",
    international: "350",
    local: "4,000",
    isRegular: true,
  },
  {
    category: "Regular: Non-NACTE Council Members",
    international: "400",
    local: "4,500",
    isRegular: true,
  },
  {
    category: "Students",
    international: "250",
    local: "2,500",
  },
  {
    category: "Participants",
    international: "150",
    local: "1,500",
  },
];

const RegistrationFee = () => {
  return (
    <section id="registration-fee" className="py-20 bg-white">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        {/* Section Header */}
        <div className="text-center mb-16">
          <h2 className="text-3xl md:text-4xl font-bold mb-4">
            Registration Fee
          </h2>
          <div className="w-20 h-1 bg-primary mx-auto rounded-full mb-6" />
          <p className="text-gray-600 max-w-2xl mx-auto">
            Conference registration fees for different categories
          </p>
        </div>

        {/* Fee Table */}
        <div className="max-w-4xl mx-auto mb-12 overflow-x-auto">
          <div className="inline-block min-w-full">
            <div className="bg-white rounded-xl shadow-sm border border-gray-200">
              <table className="min-w-full divide-y divide-gray-200">
                <thead className="bg-gray-50">
                  <tr>
                    <th
                      scope="col"
                      className="px-6 py-4 text-left text-sm font-semibold text-gray-900"
                    >
                      Category
                    </th>
                    <th
                      scope="col"
                      className="px-6 py-4 text-right text-sm font-semibold text-gray-900"
                    >
                      International Participants (USD)
                    </th>
                    <th
                      scope="col"
                      className="px-6 py-4 text-right text-sm font-semibold text-gray-900"
                    >
                      Local Participants (PKR)
                    </th>
                  </tr>
                </thead>
                <tbody className="divide-y divide-gray-200 bg-white">
                  {feeCategories.map((fee, index) => (
                    <tr
                      key={index}
                      className="hover:bg-gray-50 transition-colors"
                    >
                      <td className="px-6 py-4 text-sm">
                        <div className="flex items-center gap-2">
                          <span
                            className={`font-medium ${
                              fee.isEarlyBird || fee.isRegular
                                ? "text-primary"
                                : "text-gray-900"
                            }`}
                          >
                            {fee.isEarlyBird && "* "}
                            {fee.isRegular && "** "}
                            {fee.category}
                          </span>
                        </div>
                      </td>
                      <td className="px-6 py-4 text-sm text-gray-900 text-right">
                        ${fee.international}
                      </td>
                      <td className="px-6 py-4 text-sm text-gray-900 text-right">
                        Rs. {fee.local}
                      </td>
                    </tr>
                  ))}
                </tbody>
              </table>
            </div>
          </div>
        </div>

        {/* Notes */}
        <div className="max-w-4xl mx-auto space-y-6">
          <div className="bg-primary/5 rounded-xl p-6">
            <div className="space-y-2 text-sm text-gray-600">
              <p>* Early bird registration available until 15 April 2025</p>
              <p>** On desk registration: Rs. 5,000</p>
            </div>
          </div>

          {/* Publication Note */}
          <div className="bg-gray-50 rounded-xl p-6">
            <h3 className="text-lg font-semibold text-gray-900 mb-3">
              Publication Opportunity
            </h3>
            <p className="text-gray-600 text-sm leading-relaxed">
              Selected full papers will be invited for evaluation in the AIOU
              Journals. The selection will be made by a review committee. Please
              note that the selection of articles does not guarantee acceptance.
              Only those articles that successfully complete the editorial and
              peer-review processes of the mentioned journals will be published.
            </p>
          </div>
        </div>
      </div>
    </section>
  );
};

export default RegistrationFee;
