"use client";

import { Users } from "lucide-react";
import Image from "next/image";

interface Speaker {
  name: string;
  title?: string;
  image?: string;
  category: "national" | "international";
}

const speakers: Speaker[] = [
  {
    name: "Dr. Munawwar Mirza",
    title: "Expert in Teacher Education",
    image: "/speakers/ali.jpg",
    category: "national",
  },
  {
    name: "Dr. Sajid Ali",
    title: "Educational Leadership Specialist",
    image: "/speakers/ali.jpg",
    category: "national",
  },
  {
    name: "Dr. Abdul Rehman",
    title: "Educational Policy Expert",
    image: "/speakers/ali.jpg",
    category: "national",
  },
];

const Speakers = () => {
  return (
    <section id="speakers" className="py-20 bg-white">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        {/* Section Header */}
        <div className="text-center mb-16">
          <h2 className="text-3xl md:text-4xl font-bold mb-4">
            Keynote Speakers
          </h2>
          <div className="w-20 h-1 bg-primary mx-auto rounded-full mb-6" />
          <p className="text-gray-600 max-w-2xl mx-auto">
            Distinguished experts sharing insights on quality teacher education
          </p>
        </div>

        {/* National Speakers */}
        <div className="mb-16">
          <h3 className="text-2xl font-bold text-center mb-10 flex items-center justify-center gap-2">
            <span className="w-8 h-[2px] bg-primary/30 rounded-full" />
            <span>National Speakers</span>
            <span className="w-8 h-[2px] bg-primary/30 rounded-full" />
          </h3>

          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
            {speakers.map((speaker, index) => (
              <div
                key={index}
                className="group relative bg-gray-50 rounded-2xl p-6 hover:bg-white hover:shadow-xl transition-all duration-300 border border-gray-100"
              >
                <div className="absolute inset-0 bg-gradient-to-b from-primary/5 to-transparent rounded-2xl transition-opacity group-hover:opacity-100 opacity-0" />

                {/* Speaker Image */}
                <div className="relative mb-6 rounded-xl overflow-hidden aspect-square bg-gray-200 group-hover:shadow-lg transition-shadow">
                  <div className="absolute inset-0 bg-gradient-to-t from-black/20 to-transparent" />
                  {speaker.image ? (
                    <Image
                      src={speaker.image}
                      alt={speaker.name}
                      fill
                      className="object-cover"
                    />
                  ) : (
                    <div className="w-full h-full flex items-center justify-center bg-primary/5">
                      <Users className="w-1/3 h-1/3 text-primary/20" />
                    </div>
                  )}
                </div>

                {/* Speaker Info */}
                <div className="relative">
                  <h4 className="text-xl font-semibold text-gray-900 mb-2">
                    {speaker.name}
                  </h4>
                  {speaker.title && (
                    <p className="text-gray-600">{speaker.title}</p>
                  )}
                </div>
              </div>
            ))}
          </div>
        </div>

        {/* International Speakers */}
        <div>
          <h3 className="text-2xl font-bold text-center mb-10 flex items-center justify-center gap-2">
            <span className="w-8 h-[2px] bg-primary/30 rounded-full" />
            <span>International Speakers</span>
            <span className="w-8 h-[2px] bg-primary/30 rounded-full" />
          </h3>

          <div className="max-w-2xl mx-auto">
            <div className="bg-gray-50 rounded-2xl p-8 text-center border border-gray-100">
              <div className="w-20 h-20 bg-primary/5 rounded-full flex items-center justify-center mx-auto mb-4">
                <Users className="w-10 h-10 text-primary/30" />
              </div>
              <h4 className="text-xl font-semibold text-gray-900 mb-2">
                Coming Soon
              </h4>
              <p className="text-gray-600">
                Stay tuned for announcements about our international keynote
                speakers
              </p>
            </div>
          </div>
        </div>
      </div>
    </section>
  );
};

export default Speakers;
