"use client";

import { FileText, Mail, CheckCircle2 } from "lucide-react";

interface SubmissionStep {
  icon: JSX.Element;
  title: string;
  description: string;
}

const submissionSteps: SubmissionStep[] = [
  {
    icon: <FileText className="w-6 h-6" />,
    title: "Prepare Your Abstract",
    description: "Format your abstract according to the conference guidelines. Include your research objectives, methodology, and key findings.",
  },
  {
    icon: <Mail className="w-6 h-6" />,
    title: "Submit via Email",
    description: "Send your abstract to nacte@aiou.edu.pk. Include your full name and contact information.",
  },
  {
    icon: <CheckCircle2 className="w-6 h-6" />,
    title: "Await Confirmation",
    description: "You will receive a confirmation email within 48 hours of submission.",
  },
];

const Submission = () => {
  return (
    <section id="submission" className="py-20 bg-white">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        {/* Section Header */}
        <div className="text-center mb-16">
          <h2 className="text-3xl md:text-4xl font-bold mb-4">
            Abstract Submission
          </h2>
          <div className="w-20 h-1 bg-primary mx-auto rounded-full mb-6" />
          <p className="text-gray-600 max-w-2xl mx-auto">
            Follow these steps to submit your abstract for the conference
          </p>
        </div>

        {/* Submission Steps */}
        {/* <div className="max-w-4xl mx-auto mb-16"> */}
          {/* <div className="grid md:grid-cols-3 gap-8"> */}
            {/* {submissionSteps.map((step, index) => ( */}
               {/* <div */}
              {/* //   key={index}
              //   className="group relative bg-gray-50 rounded-xl p-6 hover:bg-white hover:shadow-xl transition-all duration-300 border border-gray-100"
              // >
              //   <div className="absolute inset-0 bg-gradient-to-b from-primary/5 to-transparent rounded-xl opacity-0 group-hover:opacity-100 transition-opacity" />
                 */}
                {/* Icon */}
                {/* <div className="relative mb-4">
                  <div className="w-12 h-12 bg-primary/10 rounded-xl flex items-center justify-center text-primary">
                    {step.icon}
                  </div>
                </div> */}

                {/* Content */}
                {/* <div className="relative">
                  <h3 className="text-lg font-semibold text-gray-900 mb-2">
                    {step.title}
                  </h3>
                  <p className="text-gray-600 text-sm">
                    {step.description}
                  </p>
                </div> */}

                {/* Step Number */}
                {/* <div className="absolute top-4 right-4 w-8 h-8 rounded-full bg-primary/5 flex items-center justify-center">
                  <span className="text-sm font-medium text-primary">
                    {index + 1}
                  </span>
                </div> */}
              {/* </div> */}
            {/* // ))}
          // </div>
        // </div> */}
        
        

        {/* Guidelines Card */}
        <div className="max-w-4xl mx-auto">
          <div className="bg-gray-50 rounded-xl p-8">
            <h3 className="text-xl font-semibold text-gray-900 mb-6">
            Instructions / Guidelines
            </h3>
            <div className="space-y-4 text-gray-600">
              <p className="flex items-start gap-2">
                <CheckCircle2 className="w-5 h-5 text-primary mt-1 flex-shrink-0" />
                <span>Abstract Submission Guidelines [
                  <a href="example.com" className="text-blue-500">
                      Click here to Download or View 
                  </a>
                ]
                </span>
              </p>
              <p className="flex items-start gap-2">
                <CheckCircle2 className="w-5 h-5 text-primary mt-1 flex-shrink-0" />
                <span>Instructions / Guidelines for Oral presentation
                [
                  <a href="example.com" className="text-blue-500">
                      Click here to Download or View 
                  </a>
                ]
                </span>
              </p>
              <p className="flex items-start gap-2">
                <CheckCircle2 className="w-5 h-5 text-primary mt-1 flex-shrink-0" />
                <span>Instructions / Guidelines for Full Length Paper
                [
                  <a href="example.com" className="text-blue-500">
                      Click here to Download or View 
                  </a>
                ]
                </span>
              </p>
              <p className="flex items-start gap-2">
                <CheckCircle2 className="w-5 h-5 text-primary mt-1 flex-shrink-0" />
                <span>Instructions / Guidelines for Poster Presentation
                [
                  <a href="example.com" className="text-blue-500">
                      Click here to Download or View 
                  </a>
                ]
                </span>
              </p>
              <p className="flex items-start gap-2">
                <CheckCircle2 className="w-5 h-5 text-primary mt-1 flex-shrink-0" />
                <span>Instructions / Guidelines for Round Table Discussion
                [
                  <a href="example.com" className="text-blue-500">
                      Click here to Download or View 
                  </a>
                ]
                </span>
              </p>
            </div>
          </div>
        </div>

        {/* Contact Info */}
        <div className="mt-12 text-center">
          <p className="text-gray-600">
            For any queries regarding submission, please contact us at{" "}
            <a
              href="mailto:nacte@aiou.edu.pk"
              className="text-primary hover:underline font-medium"
            >
              nacte@aiou.edu.pk
            </a>
          </p>
        </div>
      </div>
    </section>
  );
};

export default Submission;